==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/es-MX/admin/users/table.php <==
<?php

return array(
    'activated'  			=> 'Activo',
    'allow'  				=> 'Permitir',
    'checkedout'  			=> 'Equipos',
    'created_at' 			=> 'Creado',
    'createuser' 			=> 'Crear Usuario',
    'deny'  				=> 'Denegar',
    'email'      			=> 'Email',
    'employee_num'      	=> 'No. Empleado',
    'first_name' 			=> 'Nombre',
    'groupnotes'			=> 'Selecciona grupo que se asigna al usuario, recuerda que el usuario tiene los permisos del grupo al que se asigna.',
    'id'         			=> 'ID',
    'inherit'  				=> 'Hereda de',
    'job' 					=> 'Departamento',
    'last_login'  			=> 'Ultimo Login',
    'last_name'  			=> 'Apellidos',
    'location'  			=> 'Localización',
    'lock_passwords'		=> 'Los detalles de acceso no pueden ser cambiados en esta instalación.',
    'manager' 				=> 'Responsable',
    'managed_locations'     => 'Ubicaciones gestionadas',
    'name' 					=> 'Usuario',
    'notes'                 => 'Notas',
    'password_confirm' 		=> 'Confirmar Password',
    'password' 				=> 'Contraseña',
    'phone'  				=> 'Teléfono',
    'show_current'          => 'Mostrar usuarios actuales',
    'show_deleted'          => 'Mostrar usuarios eliminados',
    'title' 				=> 'Puesto',
	'to_restore_them'		=> 'para restaurarlos.',
    'updateuser' 			=> 'Actualizar Usuario',
    'username' 				=> 'Usuario',
	'user_deleted_text' 	=> 'Este usuario ha sido marcado como eliminado.',
    'username_note' 		=> '(Esto se usa solo para la conexión con Active Directory, no para el inicio de sesión.)',
    'cloneuser'             => 'Clonar Usuario',
    'viewusers' 			=> 'Ver Usuarios',
);

==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/es-MX/admin/users/table.php <==
<?php

return array(
    'activated'  			=> 'Activo',
    'allow'  				=> 'Permitir',
    'checkedout'  			=> 'Equipos',
    'created_at' 			=> 'Creado',
    'createuser' 			=> 'Crear Usuario',
    'deny'  				=> 'Denegar',
    'email'      			=> 'Email',
    'employee_num'      	=> 'No. Empleado',
    'first_name' 			=> 'Nombre',
    'groupnotes'			=> 'Selecciona un grupo para asignar al usuario, recuerda que un usuario toma los permisos del grupo al que están asignados. Usa ctrl+clic (o cmd+clic en MacOS) para deseleccionar grupos.',
    'id'         			=> 'ID',
    'inherit'  				=> 'Hereda de',
    'job' 					=> 'Departamento',
    'last_login'  			=> 'Ultimo Login',
    'last_name'  			=> 'Apellidos',
    'location'  			=> 'Localización',
    'lock_passwords'		=> 'Los detalles de acceso no pueden ser cambiados en esta instalación.',
    'manager' 				=> 'Responsable',
    'managed_locations'     => 'Ubicaciones gestionadas',
    'name' 					=> 'Usuario',
    'nogroup'               => 'Aún no se han creado grupos. Para añadir uno, visite: ',
    'notes'                 => 'Notas',
    'password_confirm' 		=> 'Confirmar Password',
    'password' 				=> 'Contraseña',
    'phone'  				=> 'Teléfono',
    'show_current'          => 'Mostrar usuarios actuales',
    'show_deleted'          => 'Mostrar usuarios eliminados',
    'title' 				=> 'Puesto',
	'to_restore_them'		=> 'para restaurarlos.',
    'total_assets_cost'     => "Coste total de activos",
    'updateuser' 			=> 'Actualizar Usuario',
    'username' 				=> 'Usuario',
	'user_deleted_text' 	=> 'Este usuario ha sido marcado como eliminado.',
    'username_note' 		=> '(Esto se usa solo para la conexión con Active Directory, no para el inicio de sesión.)',
    'cloneuser'             => 'Clonar Usuario',
    'viewusers' 			=> 'Ver Usuarios',
);
